@@ -1,6 +1,6 @@
 package App::PerlWatcher::Watcher;
 {
-  $App::PerlWatcher::Watcher::VERSION = '0.19';
+  $App::PerlWatcher::Watcher::VERSION = '0.20';
 }
 # ABSTRACT: Observes some external source of events and emits the result of polling them
 
@@ -9,8 +9,9 @@ use strict;
 use warnings;
 
 use App::PerlWatcher::Levels;
+use App::PerlWatcher::Memory qw /memory_patch/;
 use App::PerlWatcher::Status;
-use aliased 'App::PerlWatcher::WatcherMemory';
+
 use Carp;
 use Data::Dump::Filtered qw/dump_filtered/;
 use Smart::Comments -ENV;
@@ -21,6 +22,7 @@ use Storable qw/freeze/;
 use Moo::Role;
 
 with qw/App::PerlWatcher::Describable/;
+with qw/App::PerlWatcher::Memorizable/;
 
 
 has 'engine_config'     => ( is => 'ro', required => 1);
@@ -35,7 +37,13 @@ has 'config'            => ( is => 'lazy');
 has 'unique_id'         => ( is => 'lazy');
 
 
-has 'memory'            => ( is => 'rw');
+memory_patch(__PACKAGE__, 'active');
+
+
+memory_patch(__PACKAGE__, 'thresholds_map');
+
+
+memory_patch(__PACKAGE__, 'last_status');
 
 
 has 'poll_callback' => (is => 'rw', default => sub { sub{};  } );
@@ -54,7 +62,8 @@ use overload fallback => 1, q/""/ => sub { $_[0]->unique_id; };
 sub BUILD {
     my ($self, $init_args) = @_;
     $self->init_args($init_args);
-    $self->memory($self->_build_memory);
+    $self->_init_thresholds_map;
+    $self->active(1);
 }
 
 sub _build_config {
@@ -67,14 +76,14 @@ sub _build_config {
     return \%config;
 }
 
-sub _build_memory {
+sub _init_thresholds_map {
     my $self = shift;
     my ( $l, $r ) = (
         $self->config        -> {on} // {},
         $self->engine_config -> {defaults}->{behaviour},
     );
     my $map = calculate_threshods($l, $r);
-    return WatcherMemory->new(thresholds_map=>$map);
+    $self->thresholds_map($map);
 }
 
 sub _build_unique_id {
@@ -106,27 +115,27 @@ sub _build_unique_id {
 
 sub force_poll {
     my $self = shift;
-    $self->active(0);
-    $self->active(1);
+    $self->activate(0);
+    $self->activate(1);
 }
 
 
-sub active {
+sub activate {
     my ( $self, $value ) = @_;
     if ( defined($value) ) {
-        $self->memory->active($value);
+        $self->active($value);
         $self->watcher_guard(undef)
             unless $value;
         $self->start if $value;
     }
-    return $self->memory->active;
+    return $self->active;
 }
 
 
 sub start {
     my $self = shift;
     $self->watcher_guard( $self->build_watcher_guard )
-        if $self->memory->active;
+        if $self->active;
 }
 
 
@@ -204,22 +213,84 @@ sub _merge {
 sub interpret_result {
     my ($self, $result, $callback, $items) = @_;
 
-    my $level = $self->memory->interpret_result($result);
-
+    my $prev_status = $self->last_status;
+    my $prev_level = $prev_status && $prev_status->level;
+    my $level = $self->_interpret_result_as_level($result, $prev_level);
     $self->_emit_event($level, $callback, $items);
 }
 
+sub _interpret_result_as_level {
+    my ($self, $result, $last_level) = @_;
+    $last_level //= LEVEL_NOTICE;
+    my $threshold_map = $self->thresholds_map;
+
+    $self->memory->data->{_last_result} //= $result;
+    my ($meta_key, $opposite_key)
+        = $result ? ('ok',   'fail')
+                  : ('fail',  'ok' );
+
+    my $counter_key          =  "_$meta_key" . "_counter";
+    my $opposite_counter_key =  "_$opposite_key" . "_counter";
+
+    my $result_changed = $self->memory->data->{_last_result} ne $result;
+    # reset values
+    if ($result_changed) {
+        $self->memory->data->{$counter_key}
+            = $self->memory->data->{$opposite_counter_key}
+            = 0;
+    }
+    my $counter = ++$self->memory->data->{$counter_key};
+
+    my @levels = sort keys (%{ $threshold_map -> {$meta_key} });
+    # @levels
+    # $counter
+    my $level_key = max grep { $_ <= $counter } @levels;
+    # $level_key
+
+    my $result_level = ( defined $level_key )
+        ? $threshold_map->{$meta_key}->{$level_key}
+        : $last_level;
+    $self->memory->data->{_last_result} = $result;
+
+    return $result_level;
+}
+
 sub _emit_event {
     my ($self, $level, $callback, $items) = @_;
+    my $prev_status = $self->last_status;
+    my $prev_items = $prev_status ? $prev_status->items : undef;
+    _merge_items($prev_items, $items);
     my $status = App::PerlWatcher::Status->new(
         watcher     => $self,
         level       => $level,
         description => sub { $self->describe },
         items       => $items,
     );
+    # remember it
+    $self->last_status($status);
     $callback->($status);
 }
 
+# move the matching by content EventItems from old to new 
+sub _merge_items {
+    my ($old_items_fun, $new_items_fun) = @_;
+    return if(!$old_items_fun || !$new_items_fun);
+
+    my ($old_items, $new_items) = map { $_->() } @_;
+
+    my %copied;
+    for my $i (0 .. @$new_items-1) {
+        for my $j (0 .. @$old_items-1) {
+            if ($new_items->[$i]->content eq $old_items->[$j]->content
+                && !$copied{$j}) {
+                $new_items->[$i] = $old_items->[$j];
+                $copied{$j} = 1;
+                last;
+            }
+        }
+    }
+}
+
 # storable-methods
 sub STORABLE_freeze {
     "$_[0]";
@@ -245,13 +316,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::PerlWatcher::Watcher - Observes some external source of events and emits the result of polling them
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 ATTRIBUTES
 
@@ -277,10 +350,26 @@ PerlWatcher state is been persisted : the watcher itself isn't stored, but
 it's unique_id is stored. That guarantees that unique_id is the same between
 PerlWatcher invokations (that's why the perl internal hash funciton isn't used)
 
-=head2 memory
+=head2 active
 
-Stores current wacher state (memory). When the watcher is persisted, only it's memory
-and unique_id are stored.
+Memorizable attribute, defines, weather the current watcher is active
+
+=head2 thresholds_map
+
+The memorizable map, which represents how to interpret successul or
+unsuccessful result, i.e. which level of severity it is. It looks like:
+
+ my $map = {
+    fail => {
+        3   =>  'info',
+        5   =>  'alert',
+    },
+    ok  => { 3 => 'notice' },
+ };
+
+=head2 last_status
+
+Represents last emitted watcher status
 
 =head2 poll_callback
 
@@ -310,9 +399,9 @@ The method is responsible for building watcher_guard
 
 Immediatly polls the watched object.
 
-=head2 active
+=head2 activate
 
-Turns on and off the wacher.
+Turns on and off the wacher, remembering the state in memory
 
 =head2 start
 
@@ -334,6 +423,11 @@ items). Meant to be called from subclases, e.g.
 
  $watcher->interpret_result(0, $callback);
 
+The items can be tacken from the previous result interpreation
+if they match by content
+
+$items is an coderef, which actually returns array of items.
+
 =head1 AUTHOR
 
 Ivan Baidakou <dmol@gmx.com>
