@@ -1,12 +1,13 @@
 package App::PerlWatcher::Watcher::HTTPSimple;
 {
-  $App::PerlWatcher::Watcher::HTTPSimple::VERSION = '0.19';
+  $App::PerlWatcher::Watcher::HTTPSimple::VERSION = '0.20';
 }
 # ABSTRACT: The simple HTTP watcher, where actual http responce body is been processed by closure
 
 use 5.12.0;
 use strict;
 use warnings;
+use utf8;
 
 use App::PerlWatcher::EventItem;
 use Carp;
@@ -56,13 +57,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::PerlWatcher::Watcher::HTTPSimple - The simple HTTP watcher, where actual http responce body is been processed by closure
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
